---
title: <span class="badge builder"></span> CSVWave
---
# <span class="badge builder"></span> CSVWave

## Constructor

```python
CSVWave()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.CSVWave
```

### <span class="badge object-method"></span> labels

```python
def labels(labels: str) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> time_step

```python
def time_step(time_step: int) -> typing.Self
```

### <span class="badge object-method"></span> values_csv

```python
def values_csv(values_csv: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CSVWave](./object-CSVWave.md)
